// SSDT-UIAC-DESIGNARE-FD.dsl
// 
// Basis: Gigabyte Designare v1.0
//
// Modified for use with a Fractal Design Define R6 with Connect D1 Front Panel
// customization for USBInjectAll.kext.
//
// This SSDT contains all ports, so using it is the same as without
// a custom SSDT.  Delete ports that are not connected or ports you
// do not need.
//
// Change the UsbConnector or portType as needed to match your
// actual USB configuration.
//
// 0     USB2 Type A
// 3     USB3 Type A
//       (also for HSxx-ports connected to an USB3 port)
// 9     USB3 Type C
//       (same SSxx for both connector orientations = internal switch) 
// 10    USB3 Type C
//       (different SSxx for both connector orientations = no internal switch) 
// 255   Other
//
//
// MaciASL: https://bitbucket.org/RehabMan/os-x-maciasl-patchmatic/downloads/
//


DefinitionBlock ("", "SSDT", 2, "hack", "_UIAC", 0)
{
    Device (_SB.USBX)
    {
        Name (_ADR, Zero)  // _ADR: Address
        Method (_DSM, 4, NotSerialized)  // _DSM: Device-Specific Method
        {
            If (LNot (Arg2))
            {
                Return (Buffer (One)
                {
                     0x03                                           
                })
            }

            Return (Package (0x08)
            {
                "kUSBSleepPortCurrentLimit", 
                0x0834, 
                "kUSBSleepPowerSupply", 
                0x13EC, 
                "kUSBWakePortCurrentLimit", 
                0x0834, 
                "kUSBWakePowerSupply", 
                0x13EC
            })
        }
    }

    Device(UIAC)
    {
        Name(_HID, "UIA00000")

        Name(RMCF, Package()
        {
            "8086_a36d", Package()
            {
                "port-count", Buffer() { 23, 0, 0, 0 },     // Port number of the highest used port (e.g. SS07 = 23
                "ports", Package()
                {
//                    "HS01", Package()        // USB 3.1 Gen2 (Front Panel) not necessary, because USB-C 3.1 Gen2 needs only SS-port
//                    {
//                        "UsbConnector", 9,
//                        "port", Buffer() { 1, 0, 0, 0 },
//                    },
//                    "HS02", Package()        // not supported by the motherboard
//                    {
//                        "UsbConnector", 3,
//                        "port", Buffer() { 2, 0, 0, 0 },
//                    },
//                    "HS03", Package()        // USB 3.1 Gen2 (red, left)
//                    {
//                        "UsbConnector", 3,
//                        "port", Buffer() { 3, 0, 0, 0 },
//                    },
//                    "HS04", Package()        // USB 3.1 Gen2 (red, right)
//                    {
//                        "UsbConnector", 3,
//                        "port", Buffer() { 4, 0, 0, 0 },
//                    },
                    "HS05", Package()        // USB 3.1 Gen1 (Front Panel: USB 3.0 left)
                    {
                        "UsbConnector", 3,
                        "port", Buffer() { 5, 0, 0, 0 },
                    },
                    "HS06", Package()        // USB 3.1 Gen1 (Front Panel: USB 3.0 right)
                    {
                        "UsbConnector", 3,
                        "port", Buffer() { 6, 0, 0, 0 },
                    },
                    "HS07", Package()        // USB 3.1 Gen1 (USB hub, yellow/blue ports)
                    {
                        "UsbConnector", 3,
                        "port", Buffer() { 7, 0, 0, 0 },
                    },
                    "HS08", Package()        // USB 2 on Thunderbolt upper port
                    {
                        "UsbConnector", 3,
                        "port", Buffer() { 8, 0, 0, 0 },
                    },
                    "HS09", Package()        // USB 2.0/1.1 (top)
                    {
                        "UsbConnector", 0,
                        "port", Buffer() { 9, 0, 0, 0 },
                    },
                    "HS10", Package()        // USB 2.0/1.1 (bottom)
                    {
                        "UsbConnector", 0,
                        "port", Buffer() { 10, 0, 0, 0 },
                    },
                    "HS11", Package()        // USB 2.0/1.1 (Front Panel: right)
                    {
                        "UsbConnector", 0,
                        "port", Buffer() { 11, 0, 0, 0 },
                    },
                    "HS12", Package()        // USB 2.0/1.1 (Front Panel: left)
                    {
                        "UsbConnector", 0,
                        "port", Buffer() { 12, 0, 0, 0 },
                    },
                    "HS13", Package()        // USB 2 on Thunderbolt bottom port
                    {
                        "UsbConnector", 3,
                        "port", Buffer() { 13, 0, 0, 0 },
                    },
//                    "HS14", Package()        // DESIGNARE USB Bluetooth (CNVi)
//                    {
//                        "UsbConnector", 255,
//                        "port", Buffer() { 14, 0, 0, 0 },
//                    },
                    "SS01", Package()        // USB 3.1 Gen2 (Front Panel)
                    {
                        "UsbConnector", 9,
                        "port", Buffer() { 17, 0, 0, 0 },
                    },
//                    "SS02", Package()        // not supported by the motherboard
//                    {
//                        "UsbConnector", 3,
//                        "port", Buffer() { 18, 0, 0, 0 },
//                    },
                    "SS03", Package()        // USB 3.1 Gen2 (red, left)
                    {
                        "UsbConnector", 3,
                        "port", Buffer() { 19, 0, 0, 0 },
                    },
                    "SS04", Package()        // USB 3.1 Gen2 (red, right)
                    {
                        "UsbConnector", 3,
                        "port", Buffer() { 20, 0, 0, 0 },
                    },
                    "SS05", Package()        // USB 3.1 Gen1 (Front Panel: USB 3.0 left)
                    {
                        "UsbConnector", 3,
                        "port", Buffer() { 21, 0, 0, 0 },
                    },
                    "SS06", Package()        // USB 3.1 Gen1 (Front Panel: USB 3.0 right)
                    {
                        "UsbConnector", 3,
                        "port", Buffer() { 22, 0, 0, 0 },
                    },
                    "SS07", Package()        // USB 3.1 Gen1 (USB hub, yellow/blue ports)
                    {
                        "UsbConnector", 3,
                        "port", Buffer() { 23, 0, 0, 0 },
                    },
//                    "SS08", Package()        // not supported by the motherboard
//                    {
//                        "UsbConnector", 3,
//                        "port", Buffer() { 24, 0, 0, 0 },
//                    },
//                    "SS09", Package()        // not supported by the motherboard
//                    {
//                        "UsbConnector", 3,
//                        "port", Buffer() { 25, 0, 0, 0 },
//                    },
//                    "SS10", Package()        // not supported by the motherboard
//                    {
//                        "UsbConnector", 3,
//                        "port", Buffer() { 26, 0, 0, 0 },
//                    },
                },
            },
        })
    }
}
//EOF